import 'package:flutter/foundation.dart';

extension ListExt<E> on List<E> {
  /// Add element to this list only if not yet contained
  bool addIfAbsent(E value) {
    if (contains(value)) return false;
    add(value);
    return true;
  }

  /// If [index] is -1 add [value] to the list, else [value] will be assigned to [index] element
  void addOrUpdate(E value, {required int index}) => index == -1 ? add(value) : this[index] = value;

  /// [returns] the element of this list that is next to [current].
  /// If current is not in the list return the first element
  E nextElement(E current) => this[(indexOf(current) + 1) % length];

  /// Get enum entry from [name] or [fallback] if no entry matches given name.
  /// E.g. CrossAxisAlignment.values.fromName('center')
  E? fromName(String? name, {E? fallback}) {
    if (name == null) return fallback;
    name = name.toLowerCase();
    for (final entry in this) if (entry != null && describeEnum(entry).toLowerCase() == name) return entry;
    return fallback;
  }
}
