import 'package:flutterx_utils/src/extensions/list.dart';

extension MapExt<K, V> on Map<K, V> {
  /// Get enum entry from name at given [key] in json map or [fallback] if key is absent or no entry matches given name.
  /// E.g. json.getEnum<CrossAxisAlignment>('alignment', CrossAxisAlignment.values)
  E? getEnum<E>(String key, List<E> values, {E? fallback}) =>
      values.fromName(this[key]?.toString(), fallback: fallback);

  /// Get parametrized list from json map
  List<T>? getList<T>(String name) {
    final list = this[name] as List?;
    if (list == null) return null;
    if (list is List<T>) return list;
    return list.cast<T>();
  }
}
